pub struct Connection<T, B, E>where
T: Read + Write + Unpin,
B: Body + 'static,
E: Http2ClientConnExec<B, T> + Unpin,
B::Error: Into<Box<dyn Error + Send + Sync>>,{
inner: (PhantomData<T>, ClientTask<B, E, T>),
}Expand description
A future that processes all HTTP state for the IO object.
In most cases, this should just be spawned into an executor, so that it can process incoming and outgoing messages, notice hangups, and the like.
Instances of this type are typically created via the handshake function
Fields
inner: (PhantomData<T>, ClientTask<B, E, T>)Implementations
Sourceimpl<T, B, E> Connection<T, B, E>
impl<T, B, E> Connection<T, B, E>
Sourcepub fn is_extended_connect_protocol_enabled(&self) -> bool
pub fn is_extended_connect_protocol_enabled(&self) -> bool
Returns whether the extended CONNECT protocol is enabled or not.
This setting is configured by the server peer by sending the
SETTINGS_ENABLE_CONNECT_PROTOCOL parameter in a SETTINGS frame.
This method returns the currently acknowledged value received from the
remote.
Sourcepub fn current_max_send_streams(&self) -> usize
pub fn current_max_send_streams(&self) -> usize
Returns the current maximum send stream count.
This setting is configured in a SETTINGS_MAX_CONCURRENT_STREAMS parameter in a SETTINGS frame,
and may change throughout the connection lifetime.
Sourcepub fn current_max_recv_streams(&self) -> usize
pub fn current_max_recv_streams(&self) -> usize
Returns the current maximum receive stream count.
This setting is configured in a SETTINGS_MAX_CONCURRENT_STREAMS parameter in a SETTINGS frame,
and may change throughout the connection lifetime.