pub struct SendRequest<B> {
dispatch: UnboundedSender<Request<B>, Response<Incoming>>,
}Expand description
The sender side of an established connection.
Fields
dispatch: UnboundedSender<Request<B>, Response<Incoming>>Implementations
Sourceimpl<B> SendRequest<B>
impl<B> SendRequest<B>
Sourcepub fn poll_ready(&mut self, _cx: &mut Context<'_>) -> Poll<Result<()>>
pub fn poll_ready(&mut self, _cx: &mut Context<'_>) -> Poll<Result<()>>
Polls to determine whether this sender can be used yet for a request.
If the associated connection is closed, this returns an Error.
Sourcepub async fn ready(&mut self) -> Result<()>
pub async fn ready(&mut self) -> Result<()>
Waits until the dispatcher is ready.
If the associated connection is closed, this returns an Error.
Sourcepub fn is_ready(&self) -> bool
pub fn is_ready(&self) -> bool
Checks if the connection is currently ready to send a request.
Note
This is mostly a hint. Due to inherent latency of networks, it is possible that even after checking this is ready, sending a request may still fail because the connection was closed in the meantime.
Sourceimpl<B> SendRequest<B>where
B: Body + 'static,
impl<B> SendRequest<B>where
B: Body + 'static,
Sourcepub fn send_request(
&mut self,
req: Request<B>,
) -> impl Future<Output = Result<Response<IncomingBody>>>
pub fn send_request( &mut self, req: Request<B>, ) -> impl Future<Output = Result<Response<IncomingBody>>>
Sends a Request on the associated connection.
Returns a future that if successful, yields the Response.
req must have a Host header.
Absolute-form Uris are not required. If received, they will be serialized
as-is.
Cancel safety
Dropping the returned future is the supported way to cancel an
in-flight HTTP/2 request. The stream is reset with RST_STREAM
(CANCEL error code); the shared connection remains usable for
other in-flight and future requests. The peer is notified
immediately rather than continuing to send a response body that
would be discarded.
Sourcepub fn try_send_request(
&mut self,
req: Request<B>,
) -> impl Future<Output = Result<Response<IncomingBody>, TrySendError<Request<B>>>>
pub fn try_send_request( &mut self, req: Request<B>, ) -> impl Future<Output = Result<Response<IncomingBody>, TrySendError<Request<B>>>>
Sends a Request on the associated connection.
Returns a future that if successful, yields the Response.
Error
If there was an error before trying to serialize the request to the connection, the message will be returned as part of this error.